from setuptools import setup

setup(name='stat_distributions',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['stat_distributions'],
      author = "Nelson Tsaku",
      
      zip_safe=False)
